@@ -1589,7 +1589,7 @@ def schedules_timeline(context, team_name, history, expand, interval, intervalun
     print(f'\n On-call schedules - {rotation.lower()}')
 
     for item in result['data'][f'{rotation}']['rotations'][0]['periods']:
-        if not history and datetime.now().date() > pendulum.parse(item['startDate']):
+        if not history and pendulum.now().in_tz('UTC') > pendulum.parse(item['startDate']):
             continue
         else:
             start_dt = pendulum.parse(item['startDate']).in_tz('Europe/Amsterdam')
